OpsInfoScreen class

Inheritance

Constructors

OpsInfoScreen({Key? key, Widget customIconChild = const Icon(Icons.info, size: 32.0, color: BinoxusPayColors.blackColor), required String message, required VoidCallback onClosing, required VoidCallback goBack, bool canShowGoBackBtn = false, String title = "Info. !", required bool hiddeAllBtn, bool noTopPadding = false, Color customColor = BinoxusPayColors.blackColor})
const

Properties

canShowGoBackBtn → bool
final
customColor → Color
final
customIconChild → Widget
final
goBack → VoidCallback
final
hashCode → int
The hash code for this object.
no setterinherited
hiddeAllBtn → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
message → String
final
noTopPadding → bool
final
onClosing → VoidCallback
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited